@@ -3,7 +3,7 @@ use Evo '::Gen::Hash GEN; -Class::Meta; -Class::Common meta_of';
 use Evo '-Export *, -import';
 
 export_proxy '-Class::Common',
-  qw(init has has_overriden requires extends implements with MODIFY_CODE_ATTRIBUTES);
+  qw(init has has_overriden reg_method requires extends implements with MODIFY_CODE_ATTRIBUTES);
 
 sub import ($me, @args) {
   my $caller = caller;
@@ -34,7 +34,7 @@ Evo::Class
 
 =head1 VERSION
 
-version 0.0222
+version 0.0223
 
 =head1 DESCRIPTION
 
@@ -68,7 +68,7 @@ These advantages make C<Evo::Class> perfect for both "corporate level" and "smal
     has 'name' => 'unnamed';
     has 'gender', is => 'ro', required => 1;
     has age => check => sub($v) { $v >= 18 };
-    sub greet($self) : Public { say "I'm " . $self->name }
+    sub greet($self) { say "I'm " . $self->name }
   }
 
   my $alex = My::Human->new(gender => 'male');
@@ -100,7 +100,7 @@ These advantages make C<Evo::Class> perfect for both "corporate level" and "smal
 
     has lang => 'Perl';
 
-    sub show($self) : Public {
+    sub show($self) {
       $self->greet();
       say "I like ", $self->lang;
     }
@@ -217,7 +217,38 @@ You can also return C<(0, "CustomError")> to provide more expressive explanation
 
 =head1 CODE REUSE
 
-Method should be marked with C<:Public> if you want to reuse them; Attributes are all public;
+All methods, defined in a class (not imported) are public. Functions, imported from other modules, don't become public and don't make a mess.
+
+All attributes are public.
+
+Methods, generated somehow else, for example by C<*foo = sub {}>, can be marked as public by L</reg_method>
+
+=head2 Private methods
+
+If you want to mark a method as private, use C<: Private> attribute. You should use C<_method($self)> syntax in most of cases.
+
+  {
+
+    package My::Parent;
+    use Evo -Class, -Loaded;
+    sub public            {'public'}
+    sub private : Private { }
+
+    package My::Child;
+    use Evo -Class;
+    extends 'My::Parent';
+  };
+
+  package main;
+  use Evo;
+  my $child  = My::Child->new();
+  my $parent = My::Parent->new();
+
+  say !!$child->can('public');     # true
+  say !!$parent->can('public');    # true
+
+  say !!$child->can('private');    # false
+  say !!$parent->can('private');   # true
 
 =head2 Overriding
 
@@ -254,7 +285,7 @@ This does "extend + check implementation". Consider this example:
 
     requires 'name';
 
-    sub greet($self) : Public {
+    sub greet($self) {
       say "My name is ", $self->name, " and I'm happy!";
     }
 
@@ -275,6 +306,29 @@ C<My::Role::Happy> requires C<name> in derivered class. We could install shared
 
 You may want to use C<extends> and C<implements> separately to resolve circular requirements, for example
 
+=head2 reg_method
+
+  use Evo;
+  {
+
+    package My::Parent;
+    use Evo -Class, -Loaded;
+    no warnings 'once';
+    *foo = sub {'Foo'};
+    reg_method('foo');
+
+    package My::Child;
+    use Evo -Class;
+    extends 'My::Parent';
+
+
+  };
+
+  say My::Child->new()->foo;
+
+Because C<foo> was installed dynamically, it's not a method by default and doesn't take a part in inheritance process.
+But you can mark it as a method with this function
+
 =head1 CODE ATTRIBUTES
 
   sub foo : Override { 'OVERRIDEN'; }
