@@ -1,5 +1,6 @@
 package Evo::Class::Meta;
-use Evo 'Carp croak; -Lib monkey_patch monkey_patch_silent; -Lib::Bare; -Export *';
+use Evo
+  'Carp croak; -Lib monkey_patch monkey_patch_silent code2names names2code; -Lib::Bare; -Export *';
 use Evo '/::Util compile_attr parse_style';
 
 our @CARP_NOT
@@ -17,47 +18,101 @@ sub cached_init {
 
 sub new ($class, %opts) {
   croak "provide class" unless $opts{class};
-  bless {overriden => {}, data => {}, %opts}, $class;
+  bless {overriden => {}, requirements => {}, methods => {}, private => {}, attrs => {}, %opts},
+    $class;
 }
 
-sub _once ($self, $name, %opts) {
+sub _once ($self, $name, $key, $val) {
 
   # for case whan "has_overrined" follows "extends"
-  croak "${\$self->class} already has $name"
-    if $self->{data}{$name} && !$self->is_overriden($name);
+  croak "${\$self->class} already has \"$name\""
+    if $self->is_public($name) && !$self->is_overriden($name);
   Evo::Lib::Bare::check_subname($name) || croak(qq{"$name" is invalid name});
-  $self->{data}{$name} = \%opts;
+  $self->{$key}{$name} = $val;
+}
+
+
+sub _is_own ($class, $name, $code) {
+  my ($pkg, $realname) = code2names($code);
+  return $pkg eq $class && $realname eq $name;
+}
+
+# !!!is_public isn't an opposite to is_private
+sub is_public ($self, $name) {
+  $self->is_public_attr($name) || $self->is_public_method($name);
+}
+
+sub is_public_attr ($self, $name) {
+  return   if $self->is_private($name);
+  return 1 if $self->{attrs}{$name};
+  return;
+}
+
+sub is_public_method ($self, $name) {
+  return   if $self->is_private($name);
+  return 1 if exists $self->{methods}{$name};
+  my $class = $self->class;
+  my $code = names2code($class, $name) or return;
+  return _is_own($class, $name, $code);
+}
+
+sub mark_private ($self, $name) {
+  $self->{private}{$name}++;
+}
+
+sub is_private ($self, $name) {
+  $self->{private}{$name};
+}
+
+sub public_attrs($self) {
+  map { ($_, $self->{attrs}{$_}) }
+    grep { $self->is_public_attr($_) } Evo::Lib::Bare::list_symbols($self->class);
+}
+
+sub public_methods($self) {
+  my $class = $self->class;
+  map { ($_, names2code($class, $_)) }
+    grep { $self->is_public_method($_) } Evo::Lib::Bare::list_symbols($self->class);
+}
+
+sub requirements($self) {
+  my %all = ($self->public_attrs, $self->public_methods, $self->{requirements}->%*);
+  keys %all;
 }
 
 sub reg_requirement ($self, $name) {
-  $self->_once($name, type => 'requirement', value => 1);
+  $self->{requirements}{$name}++;
 }
 
 
-sub reg_method ($self, $name, %opts) {
-  $self->_once($name, type => 'method', value => \%opts);
+# means register external sub as method. Because every sub in the current package
+# is public by default
+sub reg_method ($self, $name) {
+  my $class = $self->class;
+
+  # check if exists
+  my $code = names2code($class, $name) or croak "$class::$name doesn't exist";
+
+  $self->_once($name, 'methods', 'public');
 }
 
+
 sub reg_attr ($self, $name, %opts) {
-  $self->cached_init(undef)->_once($name, type => 'attr', value => \%opts);
+  $self->cached_init(undef)->_once($name, attrs => \%opts);
 }
 
 sub _map ($self, $what) {
-  map { $_ => $self->{data}{$_}{value} }
-    grep { $self->{data}{$_}{type} eq $what } keys $self->{data}->%*;
+  map { $_ => $self->{public}{$_}{value} }
+    grep { $self->{public}{$_}{type} eq $what } keys $self->{public}->%*;
 }
 
-sub attrs($self)   { $self->_map('attr') }
-sub methods($self) { $self->_map('method') }
-
-sub requirements($self) { keys $self->{data}->%*; }
 
 # it's important that $self->{builder_options} never changes and is updated by ref
 sub update_builder_options ($self) {
 
   my $bo = $self->builder_options;
   %{$bo} = (known => {}, required => [], dv => {}, dfn => {}, check => {});
-  my %attrs = $self->attrs;
+  my %attrs = $self->{attrs}->%*;    # not public, all
   for my $name (keys %attrs) {
     my %o = $attrs{$name}->%*;
     $bo->{known}{$name}++;
@@ -113,8 +168,8 @@ sub is_overriden ($self, $name) {
 sub extend_with ($self, $other) {
   my $class = $self->class;
 
-  my %attrs   = $other->attrs();
-  my %methods = $other->methods();
+  my %attrs   = $other->public_attrs();
+  my %methods = $other->public_methods();
   my @names   = (keys(%attrs), keys(%methods));
 
   foreach my $name (keys %attrs) {
@@ -127,8 +182,8 @@ sub extend_with ($self, $other) {
   foreach my $name (keys %methods) {
     next if $self->is_overriden($name);
     croak qq{Class $class already can "$name", can't install method} if $class->can($name);
-    $self->reg_method($name, $methods{$name}->%*);
-    monkey_patch $class, $name, $methods{$name}{code};
+    monkey_patch $class, $name, names2code($other->class, $name);
+    $self->reg_method($name);
   }
 
   $self;
@@ -164,7 +219,7 @@ Evo::Class::Meta
 
 =head1 VERSION
 
-version 0.0222
+version 0.0223
 
 =head1 AUTHOR
 
