@@ -2,7 +2,7 @@ package Evo::Class::Role;
 use Evo '-Class::Meta; Carp croak; -Class::Common meta_of';
 use Evo '-Export *, -import';
 
-export_proxy '-Class::Common', qw(MODIFY_CODE_ATTRIBUTES requires reg_attr:has);
+export_proxy '-Class::Common', qw(MODIFY_CODE_ATTRIBUTES requires reg_attr:has reg_method);
 
 sub new : Export {
   my $class = __PACKAGE__;
@@ -29,7 +29,7 @@ Evo::Class::Role
 
 =head1 VERSION
 
-version 0.0222
+version 0.0223
 
 =head1 DESCRIPTION
 
@@ -49,7 +49,7 @@ Also can be used as "interaces"
     use Evo '-Class::Role *; -Loaded';
 
     has myattr => 'VAL';
-    sub to_lc($self) : Public { lc $self->myattr }
+    sub to_lc($self) { lc $self->myattr }
 
 
     # class
