@@ -11,11 +11,10 @@ sub _attr_handler ($pkg, $code, @attrs) {
   }
 
   foreach my $name (@good) {
-    my @names = $name ? ($name) : Evo::Lib::Bare::find_subnames($pkg, $code);
-    Evo::Export::Class::DEFAULT->add_gen($pkg, $_, sub {$code}) for @names;
+    $name or (undef, $name) = Evo::Lib::Bare::code2names($code);
+    Evo::Export::Class::DEFAULT->add_gen($pkg, $name, sub {$code});
   }
 
-
   return @bad;
 }
 
@@ -43,7 +42,7 @@ Evo::Export
 
 =head1 VERSION
 
-version 0.0222
+version 0.0223
 
 =head1 DESCRIPTION
 
