@@ -18,38 +18,45 @@ sub _opt ($level, $opt, $debug, $sock, $val = undef) {
 
 
 # not portable
-sub io_v6only : Public { _opt(IPPROTO_IPV6, IPV6_V6ONLY, v6only => @_); }
-sub io_domain : Public { _opt(SOL_SOCKET,   SO_DOMAIN,   domain => @_); }
+sub io_v6only { _opt(IPPROTO_IPV6, IPV6_V6ONLY, v6only => @_); }
+sub io_domain { _opt(SOL_SOCKET,   SO_DOMAIN,   domain => @_); }
 
 
-sub io_type : Public     { _opt(SOL_SOCKET, SO_TYPE,     type     => @_); }
-sub io_protocol : Public { _opt(SOL_SOCKET, SO_PROTOCOL, protocol => @_); }
-sub io_rcvbuf : Public   { _opt(SOL_SOCKET, SO_RCVBUF,   rcvbuf   => @_); }
-sub io_sndbuf : Public   { _opt(SOL_SOCKET, SO_SNDBUF,   sndbuf   => @_); }
+sub io_type     { _opt(SOL_SOCKET, SO_TYPE,     type     => @_); }
+sub io_protocol { _opt(SOL_SOCKET, SO_PROTOCOL, protocol => @_); }
+sub io_rcvbuf   { _opt(SOL_SOCKET, SO_RCVBUF,   rcvbuf   => @_); }
+sub io_sndbuf   { _opt(SOL_SOCKET, SO_SNDBUF,   sndbuf   => @_); }
 
-sub io_reuseaddr : Public { _opt(SOL_SOCKET, SO_REUSEADDR, reuseaddr => @_); }
-sub io_reuseport : Public { _opt(SOL_SOCKET, SO_REUSEPORT, reuseport => @_); }
+sub io_reuseaddr { _opt(SOL_SOCKET, SO_REUSEADDR, reuseaddr => @_); }
+sub io_reuseport { _opt(SOL_SOCKET, SO_REUSEPORT, reuseport => @_); }
 
-sub io_nodelay : Public { _opt(IPPROTO_TCP, TCP_NODELAY, nodelay => @_); }
+sub io_nodelay { _opt(IPPROTO_TCP, TCP_NODELAY, nodelay => @_); }
 
 
 # bind and listen croak on failures
-sub io_bind ($s, $saddr) : Public { bind($s, $saddr) or _die "bind"; $s }
-sub io_listen ($s, $n) : Public { listen($s, $n) or _die "listen"; $s }
+sub io_bind ($s, $saddr) {
+  bind($s, $saddr) or _die "bind";
+  $s;
+}
 
-sub io_local($s) : Public {
+sub io_listen ($s, $n) {
+  listen($s, $n) or _die "listen";
+  $s;
+}
+
+sub io_local($s) {
   my $saddr = getsockname($s) or return;
   net_smart_unpack($saddr);
 }
 
-sub io_remote($s) : Public {
+sub io_remote($s) {
   my $saddr = getpeername($s) or return;
   net_smart_unpack($saddr);
 }
 
-sub io_connected($s) : Public { getpeername($s) && 1 }
+sub io_connected($s) { getpeername($s) && 1 }
 
-sub io_accept($self) : Public {
+sub io_accept($self) {
   accept(my $child, $self) or return;
   bless $child, ref $self;
   $child->io_non_blocking(1);
@@ -70,7 +77,7 @@ Evo::Io::Socket
 
 =head1 VERSION
 
-version 0.0222
+version 0.0223
 
 =head1 METHODS
 
