@@ -12,18 +12,18 @@ has 'state' => PENDING;
 
 #sub assert { shift or croak join '; ', caller() }
 
-#sub value($self) :Public {
+#sub value($self) {
 #  croak "$self isn't fulfilled" unless $self->state eq FULFILLED;
 #  $self->d_v;
 #}
 #
-#sub reason($self) :Public {
+#sub reason($self) {
 #  croak "$self isn't rejected" unless $self->state eq REJECTED;
 #  $self->d_v;
 #}
 
 
-sub finally ($self, $fn) : Public {
+sub finally ($self, $fn) {
   my $d = Evo::Promise::Deferred->new(promise => ref($self)->new);
   my $onF = sub($v) {
     $d->resolve($fn->());    # need pass result because it can be a promise
@@ -36,14 +36,16 @@ sub finally ($self, $fn) : Public {
   $self->then($onF, $onR);
 }
 
-sub catch ($self, $cfn) : Public { $self->then(undef, $cfn) }
+sub catch ($self, $cfn) {
+  $self->then(undef, $cfn);
+}
 
-sub spread ($self, $fn) : Public {
+sub spread ($self, $fn) {
   $self->then(sub($ref) { $fn->($ref->@*) });
 }
 
 
-sub then : Public {
+sub then {
   my ($self, $fh, $rh) = @_;
   my $p = ref($self)->new(ref($fh) ? (d_fh => $fh) : (), ref($rh) ? (d_rh => $rh) : ());
   push $self->d_children->@*, $p;
@@ -51,20 +53,20 @@ sub then : Public {
   $p;
 }
 
-sub d_lock_in ($self, $parent) : Public {
+sub d_lock_in ($self, $parent) {
 
   #assert(!$self->d_locked);
   #assert(!$self->d_settled);
   unshift $parent->d_children->@*, $self->d_locked(1);
 }
 
-sub d_fulfill ($self, $v) : Public {
+sub d_fulfill ($self, $v) {
 
   #assert(!$self->d_settled);
   $self->d_settled(1)->state(FULFILLED)->d_v($v);
 }
 
-sub d_reject ($self, $r) : Public {
+sub d_reject ($self, $r) {
 
   #assert(!$_[0]->d_settled);
   $self->d_settled(1)->state(REJECTED)->d_v($r);
@@ -73,7 +75,7 @@ sub d_reject ($self, $r) : Public {
 # 2.3 The Promise Resolution Procedure
 # 2.3.3.2, 2.3.3.4 doesn't make sense in perl (in real world)
 # Changed term obj or func to blessed obj and can "then"
-sub d_resolve ($self, $x) : Public {
+sub d_resolve ($self, $x) {
 
   #assert(!$self->d_settled);
 
@@ -109,19 +111,19 @@ sub d_resolve ($self, $x) : Public {
 }
 
 # reject promise and call traverse with the stack of children
-sub d_reject_continue ($self, $reason) : Public {
+sub d_reject_continue ($self, $reason) {
   $self->d_reject($reason);
   $self->d_traverse;
 }
 
-sub d_resolve_continue ($self, $v) : Public {
+sub d_resolve_continue ($self, $v) {
   $self->d_resolve($v);
   return unless $self->d_settled;
   $self->d_traverse;
 }
 
 # breadth-first
-sub d_traverse($self) : Public {
+sub d_traverse($self) {
 
   my @stack = ($self);
   while (@stack) {
@@ -169,7 +171,7 @@ Evo::Promise::Class
 
 =head1 VERSION
 
-version 0.0222
+version 0.0223
 
 =head1 AUTHOR
 
